# dhbw-python ![pypi](https://img.shields.io/pypi/v/dhbw?color=gold)

DHBW lecture accompanying Python package.

**Install**

`pip install dhbw`

**Upgrade**

`pip install dhbw -U`

**Use**

`from dhbw import dasp`

**Discover**

[read the docs](https://jurihock.github.io/dhbw-python/docs/html/index.html)
